<?php

/**
 * Theme Setup
 */
if ( ! function_exists( 'bakery_food_setup' ) ) :

  function bakery_food_setup() {

    $nicdark_themename = "bakery-food";

    //translation
    load_theme_textdomain( 'bakery-food', get_template_directory().'/languages' );

    //automatic-feed-links
    add_theme_support( 'automatic-feed-links' );

    //post-formats
    add_theme_support( 'post-formats', array( 'quote', 'image', 'link', 'video', 'gallery', 'audio' ) );

    //post-thumbnails
    add_theme_support( 'post-thumbnails' );

    //title tag
    add_theme_support( 'title-tag' );

    //custom logo
    add_theme_support( 'custom-logo', array(
        'height'      => 150,
        'width'       => 650,
        'flex-height' => true,
        'flex-width'  => true,
        'header-text' => array( 'site-title','site-description' ),
    ) );

  }

endif;
add_action( 'after_setup_theme', 'bakery_food_setup' );



/**
 * Menus
 */
function nicdark_register_my_menus() {
  register_nav_menu( 'main-menu', esc_html__( 'Main Menu', 'bakery-food' ) );  
}
add_action( 'init', 'nicdark_register_my_menus' );



/**
 * Content Width
 */
if (!isset($content_width )) $content_width  = 1180;



/**
 * Sidebar
 */
function nicdark_add_sidebars() {

    // Sidebar Main
    register_sidebar(array(
        'name' =>  esc_html__('Sidebar','bakery-food'),
        'id' => 'nicdark_sidebar',
        'before_widget' => '<div id="%1$s" class="widget %2$s">',
        'after_widget' => '</div>',
        'before_title' => '<h3>',
        'after_title' => '</h3>',
    ));

}
add_action( 'widgets_init', 'nicdark_add_sidebars' );



/**
 * Scripts
 */
function nicdark_enqueue_scripts()
{
	
    //css
    wp_enqueue_style( 'bakery-food-style', get_stylesheet_uri() );
    wp_enqueue_style( 'bakery-food-fonts', nicdark_google_fonts_url(), array(), '1.0.0' );

    //comment-reply
    if ( is_singular() ) wp_enqueue_script( 'comment-reply' );

    //navigation
    wp_enqueue_script('nicdark_navigation', get_template_directory_uri() . '/js/nicdark_navigation.js', array('jquery'), false, true );

}
add_action('wp_enqueue_scripts', 'nicdark_enqueue_scripts');



/**
 * Fonts
 */
function nicdark_google_fonts_url() {
    $nicdark_font_url = '';
    if ( 'off' !== _x( 'on', 'Google font: on or off', 'bakery-food' ) ) {
        $nicdark_font_url = add_query_arg( 'family', urlencode( 'Halant:300,400,700' ), '//fonts.googleapis.com/css' );
    }
    return $nicdark_font_url;

}



/**
 * Search Widget
 */
function nicdark_custom_search_form( $nicdark_search_form ) { 
    
    $nicdark_search_form = '
    <form role="search" method="get" id="searchform" class="searchform" action="'.home_url('/').'">
        <div>
            <label class="screen-reader-text" for="s">'.esc_attr__('Search for', 'bakery-food').' :</label>
            <input type="text" value="'.get_search_query().'" placeholder="'.esc_attr__('Keyword', 'bakery-food').' ..." name="s" id="s">
            <input type="submit" id="searchsubmit" value="'.esc_attr__('Search', 'bakery-food').'">
        </div>
    </form>';
    
    return $nicdark_search_form;
} 
add_filter( 'get_search_form', 'nicdark_custom_search_form' );

